diff --git a/.gitlab-ci.yml b/.gitlab-ci.yml
new file mode 100644
index 0000000000000000000000000000000000000000..e5384a8cf9d2743a1ddee2df1f7ed5d3631399a1
--- /dev/null
+++ b/.gitlab-ci.yml
@@ -0,0 +1,29 @@
+################
+# GitLabCI template for Drupal projects.
+#
+# This template is designed to give any Contrib maintainer everything they need to test, without requiring modification.
+# It is also designed to keep up to date with Core Development automatically through the use of include files that can be centrally maintained.
+# As long as you include the project, ref and three files below, any future updates added by the Drupal Association will be used in your
+# pipelines automatically. However, you can modify this template if you have additional needs for your project.
+# The full documentation is on https://project.pages.drupalcode.org/gitlab_templates/
+################
+
+# For information on alternative values for 'ref' see https://project.pages.drupalcode.org/gitlab_templates/info/templates-version/
+# To test a Drupal 7 project, change the first include filename from .main.yml to .main-d7.yml
+include:
+  - project: $_GITLAB_TEMPLATES_REPO
+    ref: $_GITLAB_TEMPLATES_REF
+    file:
+      - "/includes/include.drupalci.main.yml"
+      - "/includes/include.drupalci.variables.yml"
+      - "/includes/include.drupalci.workflows.yml"
+
+################
+# Pipeline configuration variables are defined with default values and descriptions in the file
+# https://git.drupalcode.org/project/gitlab_templates/-/blob/main/includes/include.drupalci.variables.yml
+# Uncomment the lines below if you want to override any of the variables. The following is just an example.
+################
+# variables:
+#   SKIP_ESLINT: '1'
+#   OPT_IN_TEST_NEXT_MAJOR: '1'
+#   _CURL_TEMPLATES_REF: 'main'
diff --git a/JCarouselApiInterface.php b/JCarouselApiInterface.php
new file mode 100644
index 0000000000000000000000000000000000000000..879f0adf83b3497740f45c1bac91e283575baa56
--- /dev/null
+++ b/JCarouselApiInterface.php
@@ -0,0 +1,15 @@
+<?php
+
+namespace Drupal\jcarousel;
+
+/**
+ * Provides an interface for jcarousel constants.
+ */
+interface JCarouselApiInterface {
+
+  /**
+   * The jCarousel website base url.
+   */
+  const JCAROUSEL_WEBSITE_URL = 'https://sorgalla.com/jcarousel/';
+
+}
diff --git a/README.txt b/README.txt
index cea96144250e46fe0ff464f8e3052c8938f25a6e..75f89d6891de5598a7f5752f05713316349d2429 100644
--- a/README.txt
+++ b/README.txt
@@ -75,12 +75,14 @@ Usage
 The jCarousel module is most commonly used with the Views module to turn
 listings of images or other content into a carousel.
 
-1) Add a new view at Administration -> Structure -> Views (admin/structure/views).
+1) Add a new view at Administration -> Structure -> Views
+   (admin/structure/views).
 
 2) Change the "Display format" of the view to "jCarousel". Click the
    "Continue & Edit" button to configure the rest of the View.
 
-3) Enable views ajax and use special jCarousel pager if you need preload. jCarousel not compatible with standard pages.
+3) Enable views ajax and use special jCarousel pager if you need preload.
+jCarousel is not compatible with standard pages.
 
 4) Click on the "Settings" link next to the jCarousel Format to configure the
    options for the carousel such as the animation speed and skin.
@@ -97,10 +99,11 @@ API Usage
 
 The jcarousel_add function is deprecated in favor to Drupal 8 render API usage.
 
-If you need to use jCarousel over hardcoded images list you can enable global load of jCarousel library and configure
-each list via data atributes
+If you need to use jCarousel over hardcoded images list you can enable global
+load of jCarousel library and configure each list via data attributes
 
-The configuration options can be found at: http://sorgalla.com/projects/jcarousel/#Configuration
+The configuration options can be found at:
+http://sorgalla.com/projects/jcarousel/#Configuration
 
 A few special keys may also be provided in $settings, such as $settings['skin'],
 which can be used to apply a specific skin to the carousel. jCarousel module
@@ -111,7 +114,8 @@ Example
 -------
 
 Skin implementation
-Please add file MYMODULE.jcarousel_skins.yml into module or MYTHEME.jcarousel_skins.yml into theme
+Please add the MYMODULE.jcarousel_skins.yml file to the module or
+the MYTHEME.jcarousel_skins.yml file to the theme
 
 myskin:
   label: 'My Skin'
@@ -119,37 +123,37 @@ myskin:
   weight: 1
 
 The following code in module will add a vertical jCarousel to the page:
-  <?php
-    $output = '';
-    $renderer = \Drupal::service('renderer');
-    $images = [
-      'http://sorgalla.com/jcarousel/examples/_shared/img/img1.jpg',
-      'http://sorgalla.com/jcarousel/examples/_shared/img/img2.jpg',
-      'http://sorgalla.com/jcarousel/examples/_shared/img/img3.jpg',
-      'http://sorgalla.com/jcarousel/examples/_shared/img/img4.jpg',
-      'http://sorgalla.com/jcarousel/examples/_shared/img/img5.jpg',
-      'http://sorgalla.com/jcarousel/examples/_shared/img/img6.jpg',
+  @code
+  $output = '';
+  $renderer = \Drupal::service('renderer');
+  $images = [
+    'http://sorgalla.com/jcarousel/examples/_shared/img/img1.jpg',
+    'http://sorgalla.com/jcarousel/examples/_shared/img/img2.jpg',
+    'http://sorgalla.com/jcarousel/examples/_shared/img/img3.jpg',
+    'http://sorgalla.com/jcarousel/examples/_shared/img/img4.jpg',
+    'http://sorgalla.com/jcarousel/examples/_shared/img/img5.jpg',
+    'http://sorgalla.com/jcarousel/examples/_shared/img/img6.jpg',
+  ];
+  $items_list = [];
+  foreach ($images as $image) {
+    $items_list[] = [
+      '#theme' => 'image',
+      '#uri' => $image,
+      '#width' => '150px',
+      '#height' => '100px',
+      '#alt' => t('Image alt'),
     ];
-    $items_list = [];
-    foreach ($images as $image) {
-      $items_list[] = [
-        '#theme' => 'image',
-        '#uri' => $image,
-        '#width' => '150px',
-        '#height' => '100px',
-        '#alt' => t('Image alt'),
-      ];
-    }
-    $options = [
-      'skin' => 'tango',
-    ];
-    $jcourusel = [
-      '#theme' => 'jcarousel',
-      '#options' => $options,
-      '#items' => $items_list,
-    ];
-    $output .= $renderer->render($jcourusel);
-  ?>
+  }
+  $options = [
+    'skin' => 'tango',
+  ];
+  $jcourusel = [
+    '#theme' => 'jcarousel',
+    '#options' => $options,
+    '#items' => $items_list,
+  ];
+  $output .= $renderer->render($jcourusel);
+  @endcode
 See jCarousel help page admin/help/jcarousel for more information.
 
 Authors
diff --git a/composer.json b/composer.json
index 428fa8fef7a9f8ab03e7f2a7259ef58afa6d6fc1..e85504989959f9105f0382e69477832d4ef6cc37 100644
--- a/composer.json
+++ b/composer.json
@@ -7,7 +7,7 @@
         "Drupal"
     ],
     "type": "drupal-module",
-    "license": "GPL-2.0+",
+    "license": "GPL-2.0-or-later",
     "homepage": "https://drupal.org/project/jcarousel",
     "support": {
         "issues": "https://drupal.org/project/issues/jcarousel",
diff --git a/jcarousel.api.php b/jcarousel.api.php
index a327315275d98cce49a030b8cbbf61e9e2eaceaa..76bc11439ae57088131268167599f29537f93908 100644
--- a/jcarousel.api.php
+++ b/jcarousel.api.php
@@ -2,7 +2,7 @@
 
 /**
  * @file
- * Hooks provided by the jcarousel module.
+ * Hooks provided by the jCarousel module.
  */
 
 /**
@@ -11,25 +11,23 @@
  */
 
 /**
- * Alter the jCarousel skin definitions.
+ * Alters the jCarousel skin definitions.
  *
  * @param array $skins
- *   Associative array of skin definitions.
+ *   An associative array of skin definitions.
  */
-function hook_jcarousel_skins_alter(&$skins) {
-  // Change weight of the tango skin.
+function hook_jcarousel_skins_alter(array &$skins) {
+  // Change the weight of the tango skin.
   $skins['tango']['weight'] = 5;
 }
 
 /**
- * Alter the jCarousel options.
+ * Alters the jCarousel options.
  *
  * @param array $options
- *   Associative array of $options.
+ *   An associative array of options.
  */
-function hook_jcarousel_options_alter(&$options) {
-
-}
+function hook_jcarousel_options_alter(array &$options) {}
 
 /**
  * @} End of "addtogroup hooks".
diff --git a/jcarousel.install b/jcarousel.install
index 228e61b1b1c66c1fd54382b9dfc2367b722c3d36..89ed365d3c668dea99d53e15b0a06bb75ca774fd 100644
--- a/jcarousel.install
+++ b/jcarousel.install
@@ -2,11 +2,12 @@
 
 /**
  * @file
- * Installation and uninstallation functions.
+ * Installation, update, and uninstallation functions for the jCarousel module.
  */
 
 use Drupal\Core\Link;
 use Drupal\Core\Url;
+use Drupal\jcarousel\jCarouselApiInterface;
 
 /**
  * Implements hook_requirements().
@@ -19,14 +20,18 @@ function jcarousel_requirements($phase) {
       $jcarousel_path = _jcarousel_get_library_path('jcarousel');
 
       if (!$jcarousel_path) {
-        $url = Url::fromUri(JCAROUSEL_WEBSITE_URL);
+        $url = Url::fromUri(jCarouselApiInterface::JCAROUSEL_WEBSITE_URL);
         $link = Link::fromTextAndUrl(t('jCarousel JavaScript file'), $url)->toString();
 
         $requirements['jcarousel_js'] = [
           'title' => t('jCarousel JavaScript file'),
           'value' => t('Not Installed'),
           'severity' => REQUIREMENT_ERROR,
-          'description' => t('You need to <a href=":url">download</a> the @jcarousel and extract the entire contents of the archive into the %path directory in your Drupal installation directory.', ['@jcarousel' => $link, '%path' => 'libraries/jcarousel', ':url' => 'https://github.com/jsor/jcarousel/releases/latest']),
+          'description' => t('You need to <a href=":url">download</a> the @jcarousel and extract the entire content of the archive into the %path directory in your Drupal installation directory.', [
+            '@jcarousel' => $link,
+            '%path' => 'libraries/jcarousel',
+            ':url' => 'https://github.com/jsor/jcarousel/releases/latest',
+          ]),
         ];
       }
       else {
diff --git a/jcarousel.module b/jcarousel.module
index c0955c819a9d6d7300284e72ba5419134a6c2d03..bbfbc08e6c466fc317a3c9bdd569a4156b26e890 100644
--- a/jcarousel.module
+++ b/jcarousel.module
@@ -4,14 +4,12 @@
  * @file
  * Provides integration with 3rd party modules and the jCarousel library.
  */
-use Drupal\Core\Template\Attribute;
-use Drupal\Core\Routing\RouteMatchInterface;
+
 use Drupal\Component\Serialization\Json;
+use Drupal\Core\Routing\RouteMatchInterface;
+use Drupal\Core\Template\Attribute;
 use Drupal\Core\Url;
 
-define('JCAROUSEL_WEBSITE_URL', 'https://sorgalla.com/jcarousel/');
-
-
 /**
  * Implements hook_help().
  */
@@ -71,6 +69,9 @@ function _jcarousel_help_image_list() {
   ];
 }
 
+/**
+ * Implements a function to simple help for the new users.
+ */
 function _jcarousel_help_simple() {
   $build = [];
 
@@ -128,12 +129,15 @@ function _jcarousel_help_simple() {
     '#template' => "{{ php_code|raw}}",
     '#context' => [
       'php_code' => highlight_string($code, TRUE),
-    ]
+    ],
   ];
 
   return $build;
 }
 
+/**
+ * The vertical helper function.
+ */
 function _jcarousel_help_vertical() {
   $build = [];
 
@@ -153,7 +157,7 @@ function _jcarousel_help_vertical() {
     '#tag' => 'p',
     '#value' => t('jCarousel can accept a variety of <a href=":url">configuration options</a> via #options arguments in render array. In this example, we created a vertical carousel.', [
       ':url' => 'http://sorgalla.com/projects/jcarousel/#Configuration',
-    ])
+    ]),
   ];
 
   $images = _jcarousel_help_image_list();
@@ -216,12 +220,15 @@ function _jcarousel_help_vertical() {
     '#template' => '{{ php_code|raw }}',
     '#context' => [
       'php_code' => highlight_string($code, TRUE),
-    ]
+    ],
   ];
   return $build;
 
 }
 
+/**
+ * Implements a skins help function.
+ */
 function _jcarousel_help_skins() {
   $build = [];
 
@@ -239,7 +246,7 @@ function _jcarousel_help_skins() {
   $build[] = [
     '#type' => 'html_tag',
     '#tag' => 'p',
-    '#value' => t('The "skin" of a carousel can be changed by setting the <code>$options[\'skin\']</code> property. This skin must match one of the skins either provided by a module or matching a skin included in your theme\'s style.css file. Skins are simply a class given to the HTML list with the name "jcarousel-skin-[skin-name]". A custom skin path may be specified in <code>$options[\'skin path\']</code>, or you can use one of these module-based skins:')
+    '#value' => t('The "skin" of a carousel can be changed by setting the <code>$options[\'skin\']</code> property. This skin must match one of the skins either provided by a module or matching a skin included in your theme\'s style.css file. Skins are simply a class given to the HTML list with the name "jcarousel-skin-[skin-name]". A custom skin path may be specified in <code>$options[\'skin path\']</code>, or you can use one of these module-based skins:'),
   ];
 
   $skins = \Drupal::service('jcarousel.skins.manager')->getDefinitions();
@@ -306,12 +313,15 @@ function _jcarousel_help_skins() {
     '#template' => '{{ php_code|raw }}',
     '#context' => [
       'php_code' => highlight_string($code, TRUE),
-    ]
+    ],
   ];
   return $build;
 
 }
 
+/**
+ * Implements an events help function.
+ */
 function _jcarousel_help_events() {
   $build = [];
 
@@ -331,12 +341,13 @@ function _jcarousel_help_events() {
             \'jcarousel:create\' => \'jcarousel.createCarousel\',
           ],
         ],
-      ];</pre> </code>')
+      ];</pre> </code>'),
   ];
 
   return $build;
 
 }
+
 /**
  * Views integration hook_help() helper.
  */
@@ -373,6 +384,7 @@ function _jcarousel_help_views() {
   ];
   return $build;
 }
+
 /**
  * Backward compatibility hook_help() helper.
  */
@@ -391,7 +403,7 @@ function _jcarousel_help_backward_compatibility() {
     '#value' => t('Backward compatibility'),
   ];
 
-  $global_usage  = t('For backward compatibility in opposite to Drupal 7 implementation using jcarousel_add() you should enable jCarousel globally via <a href=":config-url">module page configuration page </a> and configure jcarousel via <a href=":attributes-url">data atributes</a>.',
+  $global_usage = t('For backward compatibility in opposite to Drupal 7 implementation using jcarousel_add() you should enable jCarousel globally via <a href=":config-url">module page configuration page </a> and configure jcarousel via <a href=":attributes-url">data atributes</a>.',
     [
       ':config-url' => Url::fromRoute('jcarousel.config')->toString(),
       ':attributes-url' => 'https://github.com/jsor/jcarousel/blob/master/examples/data-attributes/index.html',
@@ -428,23 +440,23 @@ function _jcarousel_help_backward_compatibility() {
     '#template' => "<code><pre>{{ list_html|escape }} </pre></code>",
     '#context' => [
       'list_html' => $code_html,
-    ]
+    ],
   ];
   return $build;
 }
 
 /**
- * Builds carousel from image URLs.
+ * Builds the carousel from image URLs.
  *
  * @param array $images
- *   Array of image URLs.
+ *   An array of image URLs.
  * @param array $options
  *   The carousel options.
  *
  * @return array
- *   Renderable array of carousel.
+ *   The renderable array for the carousel.
  */
-function _jcarousel_help_render_gen($images, $options = []) {
+function _jcarousel_help_render_gen(array $images, array $options = []) {
   $item_lists = [];
   foreach ($images as $image) {
     $item_lists[] = [
@@ -487,10 +499,12 @@ function jcarousel_theme() {
  * @return array
  *   An array of JS and CSS files, suitable for inclusion as an #attached array.
  *
- * @deprecated Please use render arrays with element theme 'jcarousel' instead.
+ * @deprecated in jcarousel:6.0.0 and is removed from jcarousel:7.0.0. Or later.
+ * Please use render arrays with element theme 'jcarousel' instead.
+ *
  * @see jcarousel_theme()
  */
-function jcarousel_add($options = []) {
+function jcarousel_add(array $options = []) {
   // Add the jCarousel library and any global settings.
   $attachments['library'][] = 'jcarousel/jcarousel';
   $attachments['library'][] = 'jcarousel/jcarousel.swipe';
@@ -586,7 +600,7 @@ function template_preprocess_jcarousel(&$variables) {
 
 }
 
-/*
+/**
  * Preprocess function for views-view-jcarousel.html.twig.
  */
 function template_preprocess_views_view_jcarousel(&$variables) {
@@ -630,7 +644,7 @@ function template_preprocess_views_view_jcarousel(&$variables) {
  * @return array
  *   An array of attributes.
  */
-function _jcarousel_generate_attributes($items, $options) {
+function _jcarousel_generate_attributes(array $items, array $options) {
   $attributes = [];
   $attributes['attributes'] = new Attribute();
   $attributes['attributes_wrapper'] = new Attribute();
@@ -642,7 +656,7 @@ function _jcarousel_generate_attributes($items, $options) {
   $attributes['attributes']->addClass('jcarousel');
   $attributes['attributes']->setAttribute('data-jcarousel', 'true');
 
-  // Scroll all visible elements at a time if scroll = 'auto'
+  // Scroll all visible elements at a time if scroll = 'auto'.
   $scroll = !empty($options['scroll']) ? $options['scroll'] : $options['visible'];
 
   if ($options['swipe']) {
@@ -719,7 +733,6 @@ function _jcarousel_generate_attributes($items, $options) {
   $attributes['attributes_next']->setAttribute('data-target', '+=' . $scroll);
   $attributes['attributes_next']->addClass('jcarousel-control-next');
 
-
   $attributes['attributes_wrapper']->addClass('jcarousel-' . $orientation);
 
   // Give each item a class to identify where in the carousel it belongs.
@@ -784,25 +797,25 @@ function _jcarousel_get_library_path($library) {
   if (!isset($supported_libraries[$library])) {
     return FALSE;
   }
-    // The following logic is taken from libraries_get_libraries()
-    $searchdir = [];
+  // The following logic is taken from libraries_get_libraries()
+  $searchdir = [];
 
-    // Similar to 'modules' and 'themes' directories inside an installation
-    // profile, installation profiles may want to place libraries into a
-    // 'libraries' directory.
-    $searchdir[] = 'profiles/' . \Drupal::installProfile() . '/libraries';
+  // Similar to 'modules' and 'themes' directories inside an installation
+  // profile, installation profiles may want to place libraries into a
+  // 'libraries' directory.
+  $searchdir[] = 'profiles/' . \Drupal::installProfile() . '/libraries';
 
-    // Always search libraries.
-    $searchdir[] = 'libraries';
+  // Always search libraries.
+  $searchdir[] = 'libraries';
 
-    // Also search sites/<domain>/*.
-    $searchdir[] = \Drupal::service('site.path') . '/libraries';
+  // Also search sites/<domain>/*.
+  $searchdir[] = \Drupal::service('site.path') . '/libraries';
 
-    foreach ($searchdir as $dir) {
-        if (file_exists($dir . $supported_libraries[$library]['path_min']) || file_exists($dir . $supported_libraries[$library]['path'])) {
-            return $dir . $supported_libraries[$library]['folder'];
-        }
+  foreach ($searchdir as $dir) {
+    if (file_exists($dir . $supported_libraries[$library]['path_min']) || file_exists($dir . $supported_libraries[$library]['path'])) {
+      return $dir . $supported_libraries[$library]['folder'];
     }
+  }
 
-    return FALSE;
+  return FALSE;
 }
diff --git a/jcarousel.routing.yml b/jcarousel.routing.yml
index 29ccd6babff082eba6ab669ab38171b8b9622efc..f3bb4f5eb66e7921eb70c2ed667e8de2781aff9f 100644
--- a/jcarousel.routing.yml
+++ b/jcarousel.routing.yml
@@ -1,7 +1,7 @@
 jcarousel.config:
   path: '/admin/config/jcarousel'
   defaults:
-    _form: '\Drupal\jcarousel\Form\JCarouselConfig'
+    _form: '\Drupal\jcarousel\Form\jCarouselConfig'
     _title: 'jCarousel configuration'
   requirements:
     _permission: 'administer jcarousel'
@@ -9,8 +9,9 @@ jcarousel.config:
 jcarousel.views.ajax:
   path: 'jcarousel/views/ajax'
   defaults:
-    _controller: '\Drupal\jcarousel\Controller\JcarouselViewAjaxController::ajaxView'
+    _controller: '\Drupal\jcarousel\Controller\jCarouselViewAjaxController::ajaxView'
   options:
     _theme: ajax_base_page
   requirements:
+  # There is no access restriction for this route
     _access: 'TRUE'
diff --git a/skins/default/jcarousel-default.css b/skins/default/jcarousel-default.css
index 6600436850147c5415402a274d8c216803469acd..423ae2413d31b0e3886d518d2a60badb16aa66a3 100644
--- a/skins/default/jcarousel-default.css
+++ b/skins/default/jcarousel-default.css
@@ -1,4 +1,3 @@
-
 /**
  * A simple sample carousel skin.
  *
@@ -153,7 +152,7 @@
   width: 30px;
   height: 30px;
   text-align: center;
-  background: #4E443C;
+  background: #4e443c;
   color: #fff;
   text-decoration: none;
   text-shadow: 0 0 1px #000;
diff --git a/skins/tango/jcarousel-tango.css b/skins/tango/jcarousel-tango.css
index 3d21250f5dc5d4a7e4f5722218241b9b6b55cadf..f02938a0dac7cca7aee19fc86398154a8c97a205 100644
--- a/skins/tango/jcarousel-tango.css
+++ b/skins/tango/jcarousel-tango.css
@@ -1,4 +1,3 @@
-
 /**
  * A simple sample carousel skin.
  *
@@ -168,8 +167,8 @@
 }
 .jcarousel-skin-tango.jcarousel-vertical .jcarousel-control-prev,
 .jcarousel-skin-tango.jcarousel-vertical .jcarousel-control-next {
-height: 30px;
-width: 100%;
+  height: 30px;
+  width: 100%;
 }
 
 .jcarousel-skin-tango .jcarousel-control-prev:hover,
diff --git a/src/Ajax/JcarouselAppendCommand.php b/src/Ajax/JcarouselAppendCommand.php
index a188277361dafe8c86de5916ef964ea1490af562..379c5ef3be04c3d8d4854af2580a23b5d7903da6 100644
--- a/src/Ajax/JcarouselAppendCommand.php
+++ b/src/Ajax/JcarouselAppendCommand.php
@@ -1,8 +1,4 @@
 <?php
-/**
- * @file
- * Contains \Drupal\Core\Ajax\JcarouselAppendCommand.
- */
 
 namespace Drupal\jcarousel\Ajax;
 
@@ -13,7 +9,7 @@ use Drupal\Core\Ajax\CommandWithAttachedAssetsTrait;
 /**
  * An AJAX command for adding jCarousel items dynamically.
  *
- * This command is implemented by Drupal.AjaxCommands.prototype.jcarousel_append()
+ * Command is implemented by Drupal.AjaxCommands.prototype.jcarousel_append()
  * defined in js/jcarousel.js.
  *
  * @see http://sorgalla.com/jcarousel/docs/reference/usage.html#manipulating-the-carousel
@@ -58,8 +54,7 @@ class JcarouselAppendCommand implements CommandInterface, CommandWithAttachedAss
    *
    * @var bool
    */
-  protected $stop_preload;
-
+  protected $stopPreload;
 
   /**
    * {@inheritdoc}
diff --git a/src/Controller/JcarouselViewAjaxController.php b/src/Controller/JcarouselViewAjaxController.php
index d085914e07f144af1253953d9ed7b068c968277f..936038b3101ad9ff9d26ed3642581c3b8fc6accd 100644
--- a/src/Controller/JcarouselViewAjaxController.php
+++ b/src/Controller/JcarouselViewAjaxController.php
@@ -1,23 +1,18 @@
 <?php
-/**
- * @file
- * Contains \Drupal\jcarousel\Controller\JcarouselViewAjaxController.
- */
 
 namespace Drupal\jcarousel\Controller;
 
 use Drupal\Component\Utility\UrlHelper;
-use Drupal\Core\Ajax\AppendCommand;
 use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
 use Drupal\Core\EventSubscriber\AjaxResponseSubscriber;
 use Drupal\Core\Render\BubbleableMetadata;
 use Drupal\Core\Render\RenderContext;
-use Drupal\jcarousel\Ajax\JcarouselAppendCommand;
+use Drupal\jcarousel\Ajax\jCarouselAppendCommand;
 use Drupal\views\Ajax\ViewAjaxResponse;
 use Drupal\views\Controller\ViewAjaxController;
 use Symfony\Component\HttpFoundation\Request;
-use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;
 use Symfony\Component\HttpKernel\Exception\AccessDeniedHttpException;
+use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;
 
 /**
  * Defines a controller to load a jCarousel view via AJAX.
@@ -51,10 +46,10 @@ class JcarouselViewAjaxController extends ViewAjaxController implements Containe
       // Remove all of this stuff from the query of the request so it doesn't
       // end up in pagers and tablesort URLs.
       foreach ([
-                 'view_name', 'view_display_id', 'view_args', 'view_path',
-                 'view_dom_id', 'pager_element', 'view_base_path',
-                 AjaxResponseSubscriber::AJAX_REQUEST_PARAMETER,
-               ] as $key) {
+        'view_name', 'view_display_id', 'view_args', 'view_path',
+        'view_dom_id', 'pager_element', 'view_base_path',
+        AjaxResponseSubscriber::AJAX_REQUEST_PARAMETER,
+      ] as $key) {
         $request->query->remove($key);
         $request->request->remove($key);
       }
@@ -95,7 +90,7 @@ class JcarouselViewAjaxController extends ViewAjaxController implements Containe
         $view->dom_id = $dom_id;
 
         $context = new RenderContext();
-        $preview = $this->renderer->executeInRenderContext($context, function () use ($view, $display_id, $args) {
+        $this->renderer->executeInRenderContext($context, function () use ($view, $display_id, $args) {
           return $view->preview($display_id, $args);
         });
         if (!$context->isEmpty()) {
@@ -109,7 +104,7 @@ class JcarouselViewAjaxController extends ViewAjaxController implements Containe
             if ($view->pager->total_items == PHP_INT_MAX / 2) {
               $next_page = $view->getCurrentPage() + 1;
             }
-            $response->addCommand(new JcarouselAppendCommand(".js-view-dom-id-$dom_id", $rendered_row, ['next_page' => $next_page]));
+            $response->addCommand(new jCarouselAppendCommand(".js-view-dom-id-$dom_id", $rendered_row, ['next_page' => $next_page]));
           }
         }
 
diff --git a/src/Form/JCarouselConfig.php b/src/Form/JCarouselConfig.php
index 5135c6f7d2e192c2d60044ca153236251ffe4098..b4c676777699e4fc2db1e9ddf480fa146139cb4d 100644
--- a/src/Form/JCarouselConfig.php
+++ b/src/Form/JCarouselConfig.php
@@ -1,10 +1,5 @@
 <?php
 
-/**
- * @file
- * Contains \Drupal\jcarousel\Form\JCarouselConfig.
- */
-
 namespace Drupal\jcarousel\Form;
 
 use Drupal\Core\Form\ConfigFormBase;
@@ -18,7 +13,7 @@ class JCarouselConfig extends ConfigFormBase {
   /**
    * {@inheritdoc}
    */
-  public function getFormID() {
+  public function getFormId() {
     return 'jcarousel_config';
   }
 
@@ -36,7 +31,7 @@ class JCarouselConfig extends ConfigFormBase {
     $config = $this->config('jcarousel.settings');
     $form['global_load'] = [
       '#type' => 'checkbox',
-      '#title' => t('Load jCarousel on all pages'),
+      '#title' => $this->t('Load jCarousel on all pages'),
       '#default_value' => $config->get('global_load'),
     ];
 
diff --git a/src/Plugin/Field/FieldFormatter/JCarouselFormatter.php b/src/Plugin/Field/FieldFormatter/JCarouselFormatter.php
index 5f5e6c9f0f27ed759c206f59edd85a027f9f8a7c..d692c78bb4ca9dd503ed185227424f8845935d4c 100644
--- a/src/Plugin/Field/FieldFormatter/JCarouselFormatter.php
+++ b/src/Plugin/Field/FieldFormatter/JCarouselFormatter.php
@@ -1,10 +1,7 @@
 <?php
-/**
- * @file
- * Contains \Drupal\jcarousel\Plugin\Field\FieldFormatter\JCarouselFormatter.
- */
 
 namespace Drupal\jcarousel\Plugin\Field\FieldFormatter;
+
 use Drupal\Component\Utility\Unicode;
 use Drupal\Core\Entity\EntityStorageInterface;
 use Drupal\Core\Field\FieldDefinitionInterface;
@@ -16,7 +13,6 @@ use Drupal\image\Plugin\Field\FieldFormatter\ImageFormatter;
 use Drupal\jcarousel\jCarouselSkinsManager;
 use Symfony\Component\DependencyInjection\ContainerInterface;
 
-
 /**
  * Plugin implementation of the 'jCarousel' formatter.
  *
@@ -31,14 +27,14 @@ use Symfony\Component\DependencyInjection\ContainerInterface;
 class JCarouselFormatter extends ImageFormatter implements ContainerFactoryPluginInterface {
 
   /**
-   * jCarousel Skin Manager.
+   * The jCarousel skin manager.
    *
    * @var \Drupal\jcarousel\jCarouselSkinsManager
    */
   protected $skinsManager;
 
   /**
-   * Constructs an ImageFormatter object.
+   * Constructs a new \Drupal\jcarousel\Plugin\Field\FieldFormatter\ImageFormatter object.
    *
    * @param string $plugin_id
    *   The plugin_id for the formatter.
@@ -59,7 +55,7 @@ class JCarouselFormatter extends ImageFormatter implements ContainerFactoryPlugi
    * @param \Drupal\Core\Entity\EntityStorageInterface $image_style_storage
    *   The image style storage.
    * @param \Drupal\jcarousel\jCarouselSkinsManager $skins_manager
-   *   Jcarousel Skin manager.
+   *   The jCarousel skin manager.
    */
   public function __construct($plugin_id, $plugin_definition, FieldDefinitionInterface $field_definition, array $settings, $label, $view_mode, array $third_party_settings, AccountInterface $current_user, EntityStorageInterface $image_style_storage, jCarouselSkinsManager $skins_manager) {
     parent::__construct($plugin_id, $plugin_definition, $field_definition, $settings, $label, $view_mode, $third_party_settings, $current_user, $image_style_storage);
@@ -104,7 +100,7 @@ class JCarouselFormatter extends ImageFormatter implements ContainerFactoryPlugi
       'swipe' => 1,
       'draggable' => TRUE,
       'method' => 'scroll',
-      ] + parent::defaultSettings();
+    ] + parent::defaultSettings();
   }
 
   /**
@@ -120,131 +116,131 @@ class JCarouselFormatter extends ImageFormatter implements ContainerFactoryPlugi
     }
     $skins[''] = $this->t('None');
 
-    // Number of options to provide in count-based options.
+    // The number of options to provide in count-based options.
     $start_range = range(-10, 10);
     $range = array_combine($start_range, $start_range);
     // Remove '0'.
     unset($range[0]);
-    $auto_range = ['' => t('Auto')] + array_combine(range(1, 10), range(1, 10));
+    $auto_range = ['' => $this->t('Auto')] + array_combine(range(1, 10), range(1, 10));
 
     $element['description'] = [
       '#type' => 'markup',
-      '#value' => '<div class="messages">' . t('The jCarousel style is affected by several other settings within the display. Enable the "Use AJAX" option on your display to have items loaded dynamically. The "Items to display" option will determine how many items are preloaded into the carousel on each AJAX request. Non-AJAX carousels will contain the total number of items set in the "Items to display" option. Carousels may not be used with the "Use pager" option.') . '</div>',
+      '#value' => '<div class="messages">' . $this->t('The jCarousel style is affected by several other settings within the display. Enable the "Use AJAX" option on your display to have items loaded dynamically. The "Items to display" option will determine how many items are preloaded into the carousel on each AJAX request. Non-AJAX carousels will contain the total number of items set in the "Items to display" option. Carousels may not be used with the "Use pager" option.') . '</div>',
     ];
 
     $element['wrap'] = [
       '#type' => 'select',
-      '#title' => t('Wrap content'),
+      '#title' => $this->t('Wrap content'),
       '#default_value' => $this->getSetting('wrap'),
-      '#description' => t('Specifies whether to wrap at the first/last item (or both) and jump back to the start/end.'),
+      '#description' => $this->t('Specifies whether to wrap at the first/last item (or both) and jump back to the start/end.'),
       '#options' => [
-        0 => t('Disabled'),
-        'circular' => t('Circular'),
-        'both' => t('Both'),
-        'last' => t('Last'),
-        'first' => t('First'),
+        0 => $this->t('Disabled'),
+        'circular' => $this->t('Circular'),
+        'both' => $this->t('Both'),
+        'last' => $this->t('Last'),
+        'first' => $this->t('First'),
       ],
     ];
     $element['skin'] = [
       '#type' => 'select',
-      '#title' => t('Skin'),
+      '#title' => $this->t('Skin'),
       '#default_value' => $this->getSetting('skin'),
       '#options' => $skins,
-      '#description' => t('Skins may be provided by other modules. Set to "None" if your theme includes carousel theming directly in style.css or another stylesheet. "None" does not include any built-in navigation, arrows, or positioning at all.'),
+      '#description' => $this->t('Skins may be provided by other modules. Set to "None" if your theme includes carousel theming directly in style.css or another stylesheet. "None" does not include any built-in navigation, arrows, or positioning at all.'),
     ];
     $element['responsive'] = [
       '#type' => 'checkbox',
-      '#title' => t('Responsive (number of items)'),
+      '#title' => $this->t('Responsive (number of items)'),
       '#default_value' => $this->getSetting('responsive'),
-      '#description' => t('Select this option to have the carousel automatically adjust the number of visible items and the number of items to scroll at a time based on the available width.') . ' <strong>' . t('Changing this option will override the "Visible" and "Scroll" options and set carousel orientation to "horizontal".') . '</strong>',
+      '#description' => $this->t('Select this option to have the carousel automatically adjust the number of visible items and the number of items to scroll at a time based on the available width.') . ' <strong>' . $this->t('Changing this option will override the "Visible" and "Scroll" options and set carousel orientation to "horizontal".') . '</strong>',
     ];
     $element['visible'] = [
       '#type' => 'select',
-      '#title' => t('Number of visible items'),
+      '#title' => $this->t('Number of visible items'),
       '#options' => $auto_range,
       '#default_value' => $this->getSetting('visible'),
-      '#description' => t('Set an exact number of items to show at a time. It is recommended to leave set this to "auto", in which the number of items will be determined automatically by the space available to the carousel.') . ' <strong>' . t('Changing this option will override "width" properties set in your CSS.') . '</strong>',
+      '#description' => $this->t('Set an exact number of items to show at a time. It is recommended to leave set this to "auto", in which the number of items will be determined automatically by the space available to the carousel.') . ' <strong>' . $this->t('Changing this option will override "width" properties set in your CSS.') . '</strong>',
     ];
     $element['scroll'] = [
       '#type' => 'select',
-      '#title' => t('Scroll'),
-      '#description' => t('The number of items to scroll at a time. The "auto" setting scrolls all the visible items.'),
+      '#title' => $this->t('Scroll'),
+      '#description' => $this->t('The number of items to scroll at a time. The "auto" setting scrolls all the visible items.'),
       '#options' => $auto_range,
       '#default_value' => $this->getSetting('scroll'),
     ];
     $element['auto'] = [
       '#type' => 'textfield',
-      '#title' => t('Auto-scroll after'),
+      '#title' => $this->t('Auto-scroll after'),
       '#size' => 4,
       '#maxlength' => 4,
       '#default_value' => $this->getSetting('auto'),
-      '#field_suffix' => ' ' . t('seconds'),
-      '#description' => t('Specifies how many seconds to periodically auto-scroll the content. If set to 0 (default) then autoscrolling is turned off.'),
+      '#field_suffix' => ' ' . $this->t('seconds'),
+      '#description' => $this->t('Specifies how many seconds to periodically auto-scroll the content. If set to 0 (default) then autoscrolling is turned off.'),
     ];
     $element['navigation'] = [
       '#type' => 'select',
-      '#title' => t('Enable navigation'),
+      '#title' => $this->t('Enable navigation'),
       '#options' => [
-        '' => t('None'),
-        'before' => t('Before'),
-        'after' => t('After'),
+        '' => $this->t('None'),
+        'before' => $this->t('Before'),
+        'after' => $this->t('After'),
       ],
       '#default_value' => $this->getSetting('navigation'),
-      '#description' => t('Enable a clickable navigation list to jump straight to a given page.'),
+      '#description' => $this->t('Enable a clickable navigation list to jump straight to a given page.'),
     ];
 
     $element['advanced'] = [
       '#type' => 'fieldset',
-      '#title' => t('Advanced'),
+      '#title' => $this->t('Advanced'),
       '#collapsible' => TRUE,
       '#collapsed' => TRUE,
       '#parents' => ['style_options'],
     ];
     $element['advanced']['animation'] = [
       '#type' => 'textfield',
-      '#title' => t('Animation speed'),
+      '#title' => $this->t('Animation speed'),
       '#size' => 10,
       '#maxlength' => 10,
       '#default_value' => $this->getSetting('animation'),
-      '#description' => t('The speed of the scroll animation as string in jQuery terms ("slow"  or "fast") or milliseconds as integer (See <a href="http://api.jquery.com/animate/">jQuery Documentation</a>).'),
+      '#description' => $this->t('The speed of the scroll animation as string in jQuery terms ("slow"  or "fast") or milliseconds as integer (See <a href="http://api.jquery.com/animate/">jQuery Documentation</a>).'),
     ];
     $element['advanced']['easing'] = [
       '#type' => 'textfield',
-      '#title' => t('Easing effect'),
+      '#title' => $this->t('Easing effect'),
       '#size' => 10,
       '#maxlength' => 128,
       '#default_value' => $this->getSetting('easing'),
-      '#description' => t('The name of the easing effect that you want to use such as "swing" (the default) or "linear". See list of options in the <a href="http://api.jquery.com/animate/">jQuery Documentation</a>.'),
+      '#description' => $this->t('The name of the easing effect that you want to use such as "swing" (the default) or "linear". See list of options in the <a href="http://api.jquery.com/animate/">jQuery Documentation</a>.'),
     ];
     $element['advanced']['start'] = [
       '#type' => 'select',
-      '#title' => t('Start position'),
-      '#description' => t('The item that will be shown as the first item in the list upon loading. Useful for starting a list in the middle of a set. A negative value allows choosing an item in the end, e.g. -1 is the last item.'),
+      '#title' => $this->t('Start position'),
+      '#description' => $this->t('The item that will be shown as the first item in the list upon loading. Useful for starting a list in the middle of a set. A negative value allows choosing an item in the end, e.g. -1 is the last item.'),
       '#options' => $range,
       '#default_value' => $this->getSetting('start'),
     ];
     $element['advanced']['autoPause'] = [
       '#type' => 'checkbox',
-      '#title' => t('Pause auto-scroll on hover'),
-      '#description' => t('If auto-scrolling, pause the carousel when the user hovers the mouse over an item.'),
+      '#title' => $this->t('Pause auto-scroll on hover'),
+      '#description' => $this->t('If auto-scrolling, pause the carousel when the user hovers the mouse over an item.'),
       '#default_value' => $this->getSetting('autoPause'),
     ];
     $element['advanced']['vertical'] = [
       '#type' => 'checkbox',
-      '#title' => t('Vertical'),
-      '#description' => t('Specifies wether the carousel appears in horizontal or vertical orientation. Changes the carousel from a left/right style to a up/down style carousel. Defaults to horizontal.'),
+      '#title' => $this->t('Vertical'),
+      '#description' => $this->t('Specifies wether the carousel appears in horizontal or vertical orientation. Changes the carousel from a left/right style to a up/down style carousel. Defaults to horizontal.'),
       '#default_value' => $this->getSetting('vertical'),
     ];
 
     $link_types = [
-      'content' => t('Content'),
-      'file' => t('File'),
+      'content' => $this->t('Content'),
+      'file' => $this->t('File'),
     ];
     $element['image_link'] = [
-      '#title' => t('Link image to'),
+      '#title' => $this->t('Link image to'),
       '#type' => 'select',
       '#default_value' => $this->getSetting('image_link'),
-      '#empty_option' => t('Nothing'),
+      '#empty_option' => $this->t('Nothing'),
       '#options' => $link_types,
     ];
 
@@ -280,63 +276,63 @@ class JCarouselFormatter extends ImageFormatter implements ContainerFactoryPlugi
 
     $wrap = $this->getSetting('wrap');
     if ($wrap != 0) {
-      $summary[] = t('Wrap content: @wrap', ['@wrap' => Unicode::ucfirst($wrap)]);
+      $summary[] = $this->t('Wrap content: @wrap', ['@wrap' => Unicode::ucfirst($wrap)]);
     }
 
     $skin = $this->getSetting('skin');
-    $skin_name = t('None');
+    $skin_name = $this->t('None');
     if (!empty($skin)) {
       $skins = $this->skinsManager->getDefinitions();
-      $skin_name = isset($skins[$skin]) ? $skins[$skin]['label'] : t('Broken skin !skin', ['!skin' => $skin]);
+      $skin_name = isset($skins[$skin]) ? $skins[$skin]['label'] : $this->t('Broken skin !skin', ['!skin' => $skin]);
     }
-    $summary[] = t('Skin: @skin', ['@skin' => $skin_name]);
+    $summary[] = $this->t('Skin: @skin', ['@skin' => $skin_name]);
 
     $responsive = $this->getSetting('responsive');
     if ($responsive != 0) {
-      $summary[] = t('Responsive (number of items): @responsive', ['@responsive' => $responsive]);
+      $summary[] = $this->t('Responsive (number of items): @responsive', ['@responsive' => $responsive]);
     }
 
     $visible = $this->getSetting('visible');
-    $visible_name = empty($visible) ? t('Auto') : $visible;
-    $summary[] = t('Number of visible items: @visible', ['@visible' => $visible_name]);
+    $visible_name = empty($visible) ? $this->t('Auto') : $visible;
+    $summary[] = $this->t('Number of visible items: @visible', ['@visible' => $visible_name]);
 
     $scroll = $this->getSetting('scroll');
-    $scroll_name = empty($visible) ? t('All visible') : $scroll;
-    $summary[] = t('Number of items to scroll at a time: @scroll', ['@scroll' => $scroll_name]);
+    $scroll_name = empty($visible) ? $this->t('All visible') : $scroll;
+    $summary[] = $this->t('Number of items to scroll at a time: @scroll', ['@scroll' => $scroll_name]);
 
     $auto = $this->getSetting('auto');
     if (!empty($auto)) {
-      $summary[] = t('Auto-scroll after @auto seconds', ['@auto' => $auto]);
+      $summary[] = $this->t('Auto-scroll after @auto seconds', ['@auto' => $auto]);
       $auto_pause = $this->getSetting('autoPause');
-      $auto_pause_name = $auto_pause == TRUE ? t('Yes') : t('No');
-      $summary[] = t('Pause auto-scroll on hover: @auto_pause', ['@auto_pause' => $auto_pause_name]);
+      $auto_pause_name = $auto_pause == TRUE ? $this->t('Yes') : $this->t('No');
+      $summary[] = $this->t('Pause auto-scroll on hover: @auto_pause', ['@auto_pause' => $auto_pause_name]);
     }
 
     $navigation = $this->getSetting('navigation');
-    $navigation_name = empty($navigation) ? t('Disabled') : Unicode::ucfirst($navigation);
-    $summary[] = t('Navigation: @navigation', ['@navigation' => $navigation_name]);
+    $navigation_name = empty($navigation) ? $this->t('Disabled') : Unicode::ucfirst($navigation);
+    $summary[] = $this->t('Navigation: @navigation', ['@navigation' => $navigation_name]);
 
     $animation = $this->getSetting('animation');
     if (!empty($animation)) {
       if (is_int($animation)) {
-        $summary[] = t('Navigation: @animation seconds', ['@animation' => $animation]);
+        $summary[] = $this->t('Navigation: @animation seconds', ['@animation' => $animation]);
       }
       else {
-        $summary[] = t('Navigation: @animation', ['@animation' => $animation]);
+        $summary[] = $this->t('Navigation: @animation', ['@animation' => $animation]);
       }
     }
 
     $easing = $this->getSetting('easing');
     if (!empty($easing)) {
-      $summary[] = t('Easing effect: @easing', ['@easing' => $easing]);
+      $summary[] = $this->t('Easing effect: @easing', ['@easing' => $easing]);
     }
 
     $start = $this->getSetting('start');
-    $summary[] = t('Start position: @start', ['@start' => $start]);
+    $summary[] = $this->t('Start position: @start', ['@start' => $start]);
 
     $vertical = $this->getSetting('vertical');
     if ($vertical == TRUE) {
-      $summary[] = t('Vertical: Yes');
+      $summary[] = $this->t('Vertical: Yes');
     }
 
     return $summary;
diff --git a/src/Plugin/views/pager/jcarouselPager.php b/src/Plugin/views/pager/JcarouselPager.php
similarity index 67%
rename from src/Plugin/views/pager/jcarouselPager.php
rename to src/Plugin/views/pager/JcarouselPager.php
index 243629a43cc0c788ecb4e1e517486fdd9ce5f300..2230d654e573b527d6bfce2137fc37bd3971768c 100644
--- a/src/Plugin/views/pager/jcarouselPager.php
+++ b/src/Plugin/views/pager/JcarouselPager.php
@@ -1,14 +1,11 @@
 <?php
 
-/**
- * @file
- * Contains \Drupal\views\Plugin\views\pager\jcarouselPager.
- */
 namespace Drupal\jcarousel\Plugin\views\pager;
+
 use Drupal\views\Plugin\views\pager\SqlBase;
 
 /**
- * The plugin to handle full pager.
+ * The full pager plugin.
  *
  * @ingroup views_pager_plugins
  *
@@ -20,16 +17,26 @@ use Drupal\views\Plugin\views\pager\SqlBase;
  *   theme = "jcarousel_pager",
  * )
  */
-class jcarouselPager extends SqlBase {
+class JcarouselPager extends SqlBase {
 
   /**
    * {@inheritdoc}
    */
   public function summaryTitle() {
     if (!empty($this->options['offset'])) {
-      return $this->formatPlural($this->options['items_per_page'], 'jCarousel pager, @count item, skip @skip', 'jCarousel pager, @count items, skip @skip', ['@count' => $this->options['items_per_page'], '@skip' => $this->options['offset']]);
+      return $this->formatPlural($this->options['items_per_page'],
+      'jCarousel pager, @count item, skip @skip',
+      'jCarousel pager, @count items, skip @skip', [
+        '@count' => $this->options['items_per_page'],
+        '@skip' => $this->options['offset'],
+      ]
+      );
     }
-    return $this->formatPlural($this->options['items_per_page'], 'jCarousel pager, @count item', 'jCarousel pager, @count items', ['@count' => $this->options['items_per_page']]);
+    return $this->formatPlural(
+      $this->options['items_per_page'],
+      'jCarousel pager, @count item',
+      'jCarousel pager, @count items', ['@count' => $this->options['items_per_page']]
+    );
   }
 
   /**
@@ -41,8 +48,8 @@ class jcarouselPager extends SqlBase {
     // Don't query for the next page if we have a pager that has a limited
     // amount of pages.
     if ($this->getItemsPerPage() > 0 && (empty($this->options['total_pages']) || ($this->getCurrentPage() < $this->options['total_pages']))) {
-      // Increase the items in the query in order to be able to find out whether
-      // there is another page.
+      // Increase the items in the query in order to be able to find out
+      // whether there is another page.
       $limit = $this->view->query->getLimit();
       $limit += 1;
       $this->view->query->setLimit($limit);
@@ -60,13 +67,13 @@ class jcarouselPager extends SqlBase {
    * {@inheritdoc}
    */
   public function postExecute(&$result) {
-    // In query() one more item might have been retrieved than necessary. If so,
-    // the next link needs to be displayed and the item removed.
+    // In query(), one more item than necessary might have been retrieved. If
+    // so, the next link needs to be displayed and the item removed.
     if ($this->getItemsPerPage() > 0 && count($result) > $this->getItemsPerPage()) {
       array_pop($result);
       // Make sure the pager shows the next link by setting the total items to
-      // the biggest possible number but prevent failing calculations like
-      // ceil(PHP_INT_MAX) we take PHP_INT_MAX / 2.
+      // the biggest possible number, but prevent failing calculations like
+      // ceil(PHP_INT_MAX).
       $total = PHP_INT_MAX / 2;
     }
     else {
diff --git a/src/Plugin/views/style/jcarousel.php b/src/Plugin/views/style/Jcarousel.php
similarity index 88%
rename from src/Plugin/views/style/jcarousel.php
rename to src/Plugin/views/style/Jcarousel.php
index f4a749d8b5c1d7ab874a5611f6adeb93542ad6b5..dd0fac96ca0496998c4d8c5939f6a18d8c42cf56 100644
--- a/src/Plugin/views/style/jcarousel.php
+++ b/src/Plugin/views/style/Jcarousel.php
@@ -1,14 +1,9 @@
 <?php
 
-/**
- * @file
- * Contains \Drupal\jcarousel\Plugin\views\style\jcarousel.
- */
-
 namespace Drupal\jcarousel\Plugin\views\style;
 
-use Drupal\jcarousel\jCarouselSkinsManager;
 use Drupal\Core\Form\FormStateInterface;
+use Drupal\jcarousel\jCarouselSkinsManager;
 use Drupal\views\Plugin\views\style\StylePluginBase;
 use Symfony\Component\DependencyInjection\ContainerInterface;
 
@@ -25,7 +20,7 @@ use Symfony\Component\DependencyInjection\ContainerInterface;
  *   display_types = {"normal"}
  * )
  */
-class jcarousel extends StylePluginBase {
+class Jcarousel extends StylePluginBase {
 
   /**
    * Does the style plugin allows to use style plugins.
@@ -35,7 +30,7 @@ class jcarousel extends StylePluginBase {
   protected $usesRowPlugin = TRUE;
 
   /**
-   * jCarousel Skin Manager.
+   * The jCarousel skin manager.
    *
    * @var \Drupal\jcarousel\jCarouselSkinsManager
    */
@@ -51,7 +46,7 @@ class jcarousel extends StylePluginBase {
    * @param mixed $plugin_definition
    *   The plugin implementation definition.
    * @param \Drupal\jcarousel\jCarouselSkinsManager $skins_manager
-   *   Jcarousel Skin manager.
+   *   The jCarousel Skin manager.
    */
   public function __construct(array $configuration, $plugin_id, $plugin_definition, jCarouselSkinsManager $skins_manager) {
     parent::__construct($configuration, $plugin_id, $plugin_definition);
@@ -111,11 +106,11 @@ class jcarousel extends StylePluginBase {
     $range = array_combine($start_range, $start_range);
     // Remove '0'.
     unset($range[0]);
-    $auto_range = ['' => t('Auto')] + array_combine(range(1, 10), range(1, 10));
+    $auto_range = ['' => $this->t('Auto')] + array_combine(range(1, 10), range(1, 10));
 
     $form['description'] = [
       '#type' => 'markup',
-      '#value' => '<div class="messages">' . t('The jCarousel style is affected by several other settings within the display. Enable the "Use AJAX" option on your display to have items loaded dynamically. The "Items to display" option will determine how many items are preloaded into the carousel on each AJAX request. Non-AJAX carousels will contain the total number of items set in the "Items to display" option. Carousels may not be used with the "Use pager" option.') . '</div>',
+      '#value' => '<div class="messages">' . $this->t('The jCarousel style is affected by several other settings within the display. Enable the "Use AJAX" option on your display to have items loaded dynamically. The "Items to display" option will determine how many items are preloaded into the carousel on each AJAX request. Non-AJAX carousels will contain the total number of items set in the "Items to display" option. Carousels may not be used with the "Use pager" option.') . '</div>',
     ];
 
     $form['wrap'] = [
@@ -142,19 +137,19 @@ class jcarousel extends StylePluginBase {
       '#type' => 'checkbox',
       '#title' => $this->t('Responsive (number of items)'),
       '#default_value' => $this->options['responsive'],
-      '#description' => $this->t('Select this option to have the carousel automatically adjust the number of visible items and the number of items to scroll at a time based on the available width.') . ' <strong>' . t('Changing this option will override the "Visible" and "Scroll" options and set carousel orientation to "horizontal".') . '</strong>',
+      '#description' => $this->t('Select this option to have the carousel automatically adjust the number of visible items and the number of items to scroll at a time based on the available width.') . ' <strong>' . $this->t('Changing this option will override the "Visible" and "Scroll" options and set carousel orientation to "horizontal".') . '</strong>',
     ];
     $form['visible'] = [
       '#type' => 'select',
       '#title' => $this->t('Number of visible items'),
       '#options' => $auto_range,
       '#default_value' => $this->options['visible'],
-      '#description' => $this->t('Set an exact number of items to show at a time. It is recommended to leave set this to "auto", in which the number of items will be determined automatically by the space available to the carousel.') . ' <strong>' . t('Changing this option will override "width" properties set in your CSS.') . '</strong>',
+      '#description' => $this->t('Set an exact number of items to show at a time. It is recommended to leave set this to "auto", in which the number of items will be determined automatically by the space available to the carousel.') . ' <strong>' . $this->t('Changing this option will override "width" properties set in your CSS.') . '</strong>',
     ];
     $form['scroll'] = [
       '#type' => 'select',
-      '#title' => t('Scroll'),
-      '#description' => t('The number of items to scroll at a time. The "auto" setting scrolls all the visible items.'),
+      '#title' => $this->t('Scroll'),
+      '#description' => $this->t('The number of items to scroll at a time. The "auto" setting scrolls all the visible items.'),
       '#options' => $auto_range,
       '#default_value' => $this->options['scroll'],
     ];
@@ -248,10 +243,13 @@ class jcarousel extends StylePluginBase {
    * {@inheritdoc}
    */
   public function validateOptionsForm(&$form, FormStateInterface $form_state) {
-    $errors = parent::validateOptionsForm($form, $form_state);
+    parent::validateOptionsForm($form, $form_state);
     $display = $this->view->getDisplay();
     $pager = $display->getPlugin('pager');
-    if ($pager->usePager() && !in_array($pager->getPluginId(), ['none', 'jcarousel'])) {
+    if ($pager->usePager() && !in_array($pager->getPluginId(), [
+      'none', 'jcarousel',
+    ]
+      )) {
     }
   }
diff --git a/src/jCarouselSkinsManager.php b/src/JCarouselSkinsManager.php
similarity index 84%
rename from src/jCarouselSkinsManager.php
rename to src/JCarouselSkinsManager.php
index 1b6bdabe0e787f87929e9e16399c7c5f0f393431..7dcd6ff0d902b26bd1936e672b2fad01efb31189 100644
--- a/src/jCarouselSkinsManager.php
+++ b/src/JCarouselSkinsManager.php
@@ -1,10 +1,5 @@
 <?php
 
-/**
- * @file
- * Contains \Drupal\jcarousel\jCarouselSkinsManager.
- */
-
 namespace Drupal\jcarousel;
 
 use Drupal\Core\Cache\CacheBackendInterface;
@@ -17,13 +12,12 @@ use Drupal\Core\Plugin\Factory\ContainerFactory;
 use Drupal\Core\StringTranslation\StringTranslationTrait;
 use Drupal\Core\StringTranslation\TranslationInterface;
 
-
 /**
- * Defines a jcarousel skins plugin manager to deal with skins.
+ * Defines a jcarousel skins plugin manager.
  *
- * Extension can define skins in a EXTENSION_NAME.jcarousel_skins.yml file
- * contained in the extension's base directory. Each skin has the
- * following structure:
+ * Extensions can define skins in a EXTENSION_NAME.jcarousel_skins.yml file
+ * contained in the extension's base directory. Each skin has the following
+ * structure:
  * @code
  *   MACHINE_NAME:
  *     label: STRING
@@ -31,18 +25,18 @@ use Drupal\Core\StringTranslation\TranslationInterface;
  *     weight: INTEGER
  * @endcode
  */
-class jCarouselSkinsManager extends DefaultPluginManager {
+class JCarouselSkinsManager extends DefaultPluginManager {
   use StringTranslationTrait;
 
   /**
    * {@inheritdoc}
    */
   protected $defaults = [
-    // Human readable label for skin.
+    // The uman readable label for the skin.
     'label' => '',
-    // The file containing css for the skin.
+    // The file containing the CSS styles for the skin.
     'file' => '',
-    // Weight used for ordering skins.
+    // The weight used for ordering skins.
     'weight' => 0,
   ];
 
@@ -54,7 +48,7 @@ class jCarouselSkinsManager extends DefaultPluginManager {
   protected $themeHandler;
 
   /**
    * Constructs a new BreakpointManager instance.
    *
    * @param \Drupal\Core\Extension\ModuleHandlerInterface $module_handler
    *   The module handler.
@@ -54,7 +48,7 @@ class jCarouselSkinsManager extends DefaultPluginManager {
 
   /**
-   * Constructs a new BreakpointManager instance.
+   * Constructs a new \Drupal\jcarousel\BreakpointManager object.
    *
    * @param \Drupal\Core\Extension\ModuleHandlerInterface $module_handler